@@ -15,7 +15,7 @@ COMPOSING_SYMBOLS = "/\\"
 DEFAULT_FG_COLORS = "WWWWW"
 DEFAULT_BG_COLORS = "K0000"
 
-__all__ = ["print_hist", "text_hist", "HistFormatter"]
+__all__ = ["HistFormatter", "print_hist", "text_hist"]
 
 
 class Hixel:
@@ -34,7 +34,8 @@ class Hixel:
 
         allowed = r" =|\/"
         if char not in allowed:
-            raise ValueError(f"Symbol not one of the allowed: '{allowed}'")
+            msg = f"Symbol not one of the allowed: '{allowed!r}'"
+            raise ValueError(msg)
 
         if fg == self.fg_color:
             # Combine characters if possible
@@ -52,7 +53,8 @@ class Hixel:
                 (" ", "/"): "/",
             }
             if char in compose_chars:
-                self.compose = compose_combinations.get((self.compose, char))  # type: ignore
+                if self.compose is not None:
+                    self.compose = compose_combinations.get((self.compose, char))
             else:
                 self.character = char_combinations.get((self.character, char), char)
         elif char != " ":
@@ -104,7 +106,7 @@ class Hixel:
         subs = {
             "|": "\u2502",
             "=": "\u2550",
-            "#": "\u256A",
+            "#": "\u256a",
             "\\": "\u20e5",
             "/": "\u20eb",
             "X": "\u20e5\u20eb",
@@ -147,7 +149,7 @@ class Hixel:
             fg = subs[fg]
             bg = subs[bg] + 10
 
-            ret += "\033[%d;%dm" % (fg, bg)
+            ret += f"\033[{fg:d};{bg:d}m"
         return ret
 
 
@@ -195,7 +197,7 @@ class BinFormatter:
         self,
         scale=1.0,
         count_area=True,
-        tick_format="% #7.3f ",
+        tick_format="{: #7.3f} ",
         tick_mark="_",
         no_tick_mark=" ",
         print_top_edge=False,
@@ -208,7 +210,7 @@ class BinFormatter:
         self.scale = scale
         self.count_area = count_area
         self.tick_format = tick_format
-        self.tick_format_width = len(tick_format % (0.0,))
+        self.tick_format_width = len(tick_format.format(0.0))
         self.tick_mark = tick_mark
         self.no_tick_mark = no_tick_mark
         self.print_top_edge = print_top_edge
@@ -229,6 +231,7 @@ class BinFormatter:
                 self.use_color = False
         else:
             self.use_color = use_color
+        self.compose: Optional[str] = None
 
     def format_bin(self, top, bottom, counts, width=1):
         """Return a string that represents the bin.
@@ -248,10 +251,7 @@ class BinFormatter:
         """
 
         # Adjust scale by width if area represents counts
-        if self.count_area:
-            scale = self.scale * width
-        else:
-            scale = self.scale
+        scale = self.scale * (width if self.count_area else 1)
 
         if scale == 0:
             scale = 1.0
@@ -265,7 +265,7 @@ class BinFormatter:
                 self.compose = " "
                 break
         else:
-            self.compose = None  # type: ignore
+            self.compose = None
 
         # Format bin
         bin_string = ""
@@ -293,18 +293,17 @@ class BinFormatter:
                             Hixel(s, fg, bg, self.use_color, self.compose)
                             for _ in range(h)
                         ]
+                    # Overlay histograms
+                    elif h > len(line):
+                        for hix in line:
+                            hix.add(s, fg, bg)
+                        line += [
+                            Hixel(s, fg, bg, self.use_color, self.compose)
+                            for _ in range(h - len(line))
+                        ]
                     else:
-                        # Overlay histograms
-                        if h > len(line):
-                            for hix in line:
-                                hix.add(s, fg, bg)
-                            line += [
-                                Hixel(s, fg, bg, self.use_color, self.compose)
-                                for _ in range(h - len(line))
-                            ]
-                        else:
-                            for hix in line[:h]:
-                                hix.add(s, fg, bg)
+                        for hix in line[:h]:
+                            hix.add(s, fg, bg)
 
             for hix in line:
                 bin_string += hix.render()
@@ -316,7 +315,7 @@ class BinFormatter:
 
     def tick(self, edge):
         """Format the tick mark of a bin."""
-        return self.tick_format % (edge,) + self.tick_mark
+        return self.tick_format.format(edge) + self.tick_mark
 
     def no_tick(self):
         """Format the axis without a tick mark."""
@@ -444,17 +443,11 @@ class HistFormatter:
             tot_c = np.max(counts, axis=0)
 
         # Get bin lengths
-        if self.bin_formatter.count_area:
-            # Bin content will be divided by number of lines
-            c = tot_c / self.bin_lines
-        else:
-            c = tot_c
+        # Bin content will be divided by number of lines
+        c = tot_c / self.bin_lines if self.bin_formatter.count_area else tot_c
 
         # Set a scale so that largest bin fills width of allocated area
-        if self.max_count is None:
-            max_c = np.max(c)
-        else:
-            max_c = self.max_count
+        max_c = np.max(c) if self.max_count is None else self.max_count
 
         symbol_scale = max_c / hist_width
         self.bin_formatter.scale = symbol_scale * 0.999  # <- avoid rounding issues
@@ -463,7 +456,7 @@ class HistFormatter:
 
         # Write the title line
         if len(self.title):
-            hist_string += ("{: ^%ds}\n" % (self.columns,)).format(self.title)
+            hist_string += f"{self.title: ^{self.columns:d}s}\n"
 
         # Get bin edges
         top = np.array(self.edges[:-1])
@@ -475,19 +468,14 @@ class HistFormatter:
 
         # Write the first tick, common exponent and horizontal axis
         hist_string += self.bin_formatter.tick(top[0])
-        if common_exponent != 0:
-            ce_string = " x 10^%+03d" % (common_exponent,)
-        else:
-            ce_string = ""
+        ce_string = f" x 10^{common_exponent:+03.0f}" if common_exponent != 0 else ""
 
         hist_string += ce_string
         if self.bin_formatter.count_area:
             longest_count = f"{max_c:g}/row"
         else:
             longest_count = f"{max_c:g}"
-        hist_string += ("{:>%ds} \u2577\n" % (hist_width - len(ce_string) - 2,)).format(
-            longest_count
-        )
+        hist_string += f"{longest_count:>{hist_width - len(ce_string) - 2:d}s} \u2577\n"
 
         # Write the bins
         for c, t, b, w in zip(counts.T, top, bottom, self.bin_lines):
@@ -518,13 +506,13 @@ class HistFormatter:
             cycle(self.bin_formatter.bg_colors),
         ):
             # Pad label to make room for numbers below
-            lab = f"{lab:<9}"
+            pad_lab = f"{lab:<9}"
             label = " "
             label += Hixel(
                 s, fg, bg, self.bin_formatter.use_color, self.bin_formatter.compose
             ).render()
-            label += " " + lab
-            label_widths.append(3 + len(lab))
+            label += " " + pad_lab
+            label_widths.append(3 + len(pad_lab))
             summary += label
         pad = max(self.columns - (5 + np.sum(label_widths)), 0) // 2
         summary = " " * pad + summary
@@ -536,7 +524,7 @@ class HistFormatter:
         # Second line: Total
         summary += " " * pad + "Tot:"
         for c, w in zip(counts, label_widths):
-            tot = np.sum(c)
+            tot = float(np.sum(c))
             summary += f" {tot: .2e}" + " " * (w - 10)
         summary += "\n"
 
@@ -544,7 +532,7 @@ class HistFormatter:
         summary += " " * pad + "Avg:"
         for c, w in zip(counts, label_widths):
             try:
-                average = np.average(bin_values, weights=c)
+                average = float(np.average(bin_values, weights=c))
             except ZeroDivisionError:
                 average = np.nan
             summary += f" {average: .2e}" + " " * (w - 10)
@@ -554,7 +542,7 @@ class HistFormatter:
         summary += " " * pad + "Std:"
         for c, w in zip(counts, label_widths):
             try:
-                average = np.average(bin_values, weights=c)
+                average = float(np.average(bin_values, weights=c))
                 std = np.sqrt(np.average((bin_values - average) ** 2, weights=c))
             except ZeroDivisionError:
                 std = np.nan
@@ -577,7 +565,7 @@ def get_plottable_protocol_bin_edges(axis):
     ), f"Currently only support non-discrete axes {axis}"
     # TODO: Support discreete axes
     out[0] = axis[0][0]
-    out[1:] = [axis[i][1] for i in range(len(axis))]  # type: ignore
+    out[1:] = [axis[i][1] for i in range(len(axis))]
     return out
 
 
@@ -605,7 +593,7 @@ def get_count_edges(hist):
     return count, edges
 
 
-def print_hist(hist, file=None, **kwargs):  # noqa: B008
+def print_hist(hist, file=None, **kwargs):
     """Plot the output of ``numpy.histogram`` to the console.
 
     Parameters
